@@ -1,6 +1,6 @@
 package Proc::tored::PidFile;
 # ABSTRACT: Manage a service using a pid file
-$Proc::tored::PidFile::VERSION = '0.16';
+$Proc::tored::PidFile::VERSION = '0.17';
 
 use warnings;
 use strict;
@@ -15,7 +15,7 @@ use Types::Standard -types;
 
 has file_path => (is => 'ro', isa => Str);
 
-has file => (is => 'lazy', isa => InstanceOf['Path::Tiny']);
+has file => (is => 'lazy', isa => InstanceOf['Path::Tiny'], handles => ['touch']);
 sub _build_file { path(shift->file_path) }
 
 has write_lock_file => (is => 'lazy', isa => InstanceOf['Path::Tiny']);
@@ -119,13 +119,13 @@ Proc::tored::PidFile - Manage a service using a pid file
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
   use Proc::tored::PidFile;
 
-  my $pidfile = Proc::tored::PidFile->new($pid_file_path);
+  my $pidfile = Proc::tored::PidFile->new(file_path => $pid_file_path);
 
   if (my $lock = $pidfile->lock) {
     run_service;
